@@ -8,8 +8,8 @@ logger = logging.getLogger(__name__)
 class CactiParser:
     
     cacti_path = os.path.dirname(os.path.realpath(__file__))
-    MEM_POOL_PATH = f'{cacti_path}/cacti-master/example_mem_pool.yaml'  # Path to cached cacti simulated memories
-    CACTI_TOP_PATH = f'{cacti_path}/cacti-master/cacti_top.py'  # Path to cacti python script to extract costs
+    MEM_POOL_PATH = f'{cacti_path}/cacti_master/example_mem_pool.yaml'  # Path to cached cacti simulated memories
+    CACTI_TOP_PATH = f'{cacti_path}/cacti_master/cacti_top.py'  # Path to cacti python script to extract costs
 
     def __init__(self):
         pass
@@ -49,11 +49,16 @@ class CactiParser:
                             '--rd_wr_port', str(rw_port),
                             '--bank_count', str(bank),
                             '--mem_pool_path', str(mem_pool_path)])
+        
+        if p != 0:
+            raise ChildProcessError(f"Cacti subprocess call failed with return value {p}.")
 
-        # os.chdir("../../../..")
 
-    def get_item(self, mem_type, size, r_bw, r_port, w_port, rw_port, bank, mem_pool_path=MEM_POOL_PATH, cacti_top_path=CACTI_TOP_PATH):  
-        print(f"Extracting memory costs with CACTI for size = {size} and r_bw = {r_bw}")
+    def get_item(self, mem_type, size, r_bw, r_port, w_port, rw_port, bank, mem_pool_path=MEM_POOL_PATH, cacti_top_path=CACTI_TOP_PATH): 
+        if not os.path.exists(cacti_top_path):
+            raise FileNotFoundError(f"Cacti top file doesn't exist: {cacti_top_path}.")
+
+        logger.info(f"Extracting memory costs with CACTI for size = {size} and r_bw = {r_bw}")
 
         if mem_type == 'rf':
             mem_type = 'sram'
@@ -65,8 +70,8 @@ class CactiParser:
         if not self.item_exists(mem_type, size, r_bw, r_port, w_port, rw_port, bank, mem_pool_path):
             self.create_item(mem_type, size, r_bw, r_port, w_port, rw_port, bank, mem_pool_path, cacti_top_path) 
 
-        memory_pool_file = open(mem_pool_path)
-        memory_pool = yaml.full_load(memory_pool_file)
+        with open(mem_pool_path, "r") as fp:
+            memory_pool = yaml.full_load(fp)
         
         if memory_pool != None:
             for instance in memory_pool:
