@@ -151,7 +151,7 @@ class CostModelEvaluation:
     Class that stores inputs and runs them through the zigzag cost model.
     """
 
-    def __init__(self, *, accelerator, layer, spatial_mapping, temporal_mapping):
+    def __init__(self, *, accelerator, layer, spatial_mapping, temporal_mapping, access_same_data_considered_as_no_access=True):
         """
         Initialize the cost model evaluation with the following inputs:
         - accelerator: the accelerator that includes the core on which to run the layer
@@ -174,6 +174,7 @@ class CostModelEvaluation:
         self.layer = layer
         self.spatial_mapping = spatial_mapping
         self.temporal_mapping = temporal_mapping
+        self.access_same_data_considered_as_no_access = access_same_data_considered_as_no_access
 
         self.core_id = layer.core_allocation
         self.mem_instance_list = accelerator.get_core(self.core_id).get_memory_hierarchy().mem_instance_list
@@ -189,8 +190,9 @@ class CostModelEvaluation:
         Later the fractional one is used for calculating energy, and the integer one is used for calculating latency'''
         self.spatial_mapping_dict_int = spatial_mapping_fractional_to_int(self.spatial_mapping.mapping_dict_origin)
 
-        self.mapping = Mapping(self.spatial_mapping, self.temporal_mapping, self.layer)
-        self.mapping_int = Mapping(self.spatial_mapping_dict_int, self.temporal_mapping, self.layer)
+        # For constructing Mapping object,  the last parameter "self.access_same_data_considered_as_no_access" is optional
+        self.mapping = Mapping(self.accelerator, self.spatial_mapping, self.temporal_mapping, self.layer, self.access_same_data_considered_as_no_access)
+        self.mapping_int = Mapping(self.accelerator, self.spatial_mapping_dict_int, self.temporal_mapping, self.layer, self.access_same_data_considered_as_no_access)
 
         self.active_mem_level = self.mapping.mem_level
 
@@ -210,7 +212,7 @@ class CostModelEvaluation:
         return {
             "outputs": {
                 "memory": {
-                    "utilization": self.mem_utili_shared,
+                    "utilization": self.mem_utili_shared if hasattr(self, "mem_utili_shared") else None,
                     "word_accesses": self.memory_word_access
                 },
                 "energy": {
@@ -229,8 +231,8 @@ class CostModelEvaluation:
             "inputs": {
                 "accelerator": self.accelerator,
                 "layer": self.layer,
-                "spatial_mapping": self.spatial_mapping,
-                "temporal_mapping": self.temporal_mapping,
+                "spatial_mapping": self.spatial_mapping if hasattr(self, "spatial_mapping") else None,
+                "temporal_mapping": self.temporal_mapping if hasattr(self, "temporal_mapping") else None,
             },
         }
 
@@ -350,13 +352,15 @@ class CostModelEvaluation:
                                           (self.spatial_mapping.unit_unique[layer_op][mem_lv] / self.spatial_mapping.unit_unique[layer_op][mem_lv + 1])
                         data_elem_move_per_cycle_in_a_period = min((another_side_bw/data_precision), (max_bw/data_precision), data_elem_move_per_period)
                         cycle_in_a_period = ceil(data_elem_move_per_period / data_elem_move_per_cycle_in_a_period)
+                        rd_out_to_low = ceil((data_elem_move_per_cycle_in_a_period * data_precision) / min_bw) * \
+                                        (min_bw / max_bw) * \
+                                        total_period_count * cycle_in_a_period * \
+                                        self.mapping.spatial_mapping.unit_count[layer_op][mem_lv + 1]
                     else:
-                        data_elem_move_per_cycle_in_a_period = data_elem_move_per_period
-                        cycle_in_a_period = 1
-                    rd_out_to_low = ceil((data_elem_move_per_cycle_in_a_period * data_precision) / min_bw) * \
-                                    (min_bw / max_bw) * \
-                                    total_period_count * cycle_in_a_period * \
-                                    self.mapping.spatial_mapping.unit_count[layer_op][mem_lv + 1]
+                        rd_out_to_low = ceil((data_elem_move_per_period * data_precision) / min_bw) * \
+                                        (min_bw / max_bw) * \
+                                        total_period_count * \
+                                        self.mapping.spatial_mapping.unit_count[layer_op][mem_lv + 1]
 
                 ''' rd_out_to_high '''
                 data_elem_move_per_period = self.mapping.unit_mem_data_movement[layer_op][mem_lv].data_trans_amount_per_period.rd_out_to_high
